import bcrypt from 'bcryptjs'
import jwt from 'jsonwebtoken'

export function createPasswordHash(password) { 
    const salt = bcrypt.genSaltSync(10)
    const hash = bcrypt.hashSync(password, salt)
    return hash
}

export function validatePassword(password, hash) { 
    const res = bcrypt.compareSync(password, hash)
    return res
}

export function makeJwt(data, secret, expiresIn) { 
    const token = jwt.sign(data, secret, { expiresIn: expiresIn || '1h' })
    return token
}

export function decodeJwt(token, secret) { 
    //try {
        const decoded = jwt.verify(token, secret)
        return decoded
    // } catch (e) { 
    //     console.log('ERR: ', e.message)
    // }
}

export function setCookieHttpResponse(token) { 
    const date = () => {
        const now = new Date()
        const date = new Date(now.setDate(now.getDate() + 5))
        return date
    }

    return {
        statusCode: 200,
        headers: {
            'Set-Cookie': `jwt=${
               token
            }; Expires=${date()};path=/; SameSite=Strict; Secure;`
        },
        body: JSON.stringify({
            status: 'success'
        })
    }
}

export function getJwtCookieFromtApiEvent(event) { 
    const headers = event.headers
    const cookie =
        headers.cookie && headers.cookie.startsWith('jwt=')
            ? headers.cookie.split('=')[1]
            : 'no cookie set'

    if (cookie === 'no cookie set') {
        return false
    }
    return jwt
}
